@@ -23,6 +23,7 @@ import (
 const (
 	kubeSystemNamespace = "kube-system"
 	vpcCNIName          = "vpc-cni"
+	ebsCSIDriverName    = "aws-ebs-csi-driver"
 )
 
 func (a *Manager) Create(addon *api.Addon, wait bool) error {
@@ -67,27 +68,28 @@ func (a *Manager) Create(addon *api.Addon, wait bool) error {
 				return err
 			}
 			createAddonInput.ServiceAccountRoleArn = &outputRole
-		} else {
-			policies := a.getRecommendedPolicies(addon)
-			if len(policies) != 0 {
-				logger.Info("creating role using recommended policies")
-				addon.AttachPolicyARNs = policies
-				resourceSet := builder.NewIAMRoleResourceSetWithAttachPolicyARNs(addon.Name, namespace, serviceAccount, addon.PermissionsBoundary, addon.AttachPolicyARNs, a.oidcManager)
-				if err := resourceSet.AddAllResources(); err != nil {
-					return err
-				}
-				err := a.createStack(resourceSet, addon)
-				if err != nil {
-					return err
-				}
-				createAddonInput.ServiceAccountRoleArn = &resourceSet.OutputRole
-			} else {
-				logger.Info("no recommended policies found, proceeding without any IAM")
+		} else if a.hasRecommendedPolicies(addon) {
+			logger.Info("creating role using recommended policies")
+			attachPolicyARNs, wellKnownPolicies := a.getRecommendedPolicies(addon)
+
+			if attachPolicyARNs != nil {
+				addon.AttachPolicyARNs = attachPolicyARNs
 			}
+			if wellKnownPolicies != nil {
+				addon.WellKnownPolicies = *wellKnownPolicies
+			}
+
+			outputRole, err := a.createRole(addon, namespace, serviceAccount)
+			if err != nil {
+				return err
+			}
+			createAddonInput.ServiceAccountRoleArn = &outputRole
+		} else {
+			logger.Info("no recommended policies found, proceeding without any IAM")
 		}
 	} else {
 		//if any sort of policy is set or could be set, log a warning
-		if addon.ServiceAccountRoleARN != "" || hasPoliciesSet(addon) || len(a.getRecommendedPolicies(addon)) != 0 {
+		if addon.ServiceAccountRoleARN != "" || hasPoliciesSet(addon) || a.hasRecommendedPolicies(addon) {
 			logger.Warning("OIDC is disabled but policies are required/specified for this addon. Users are responsible for attaching the policies to all nodegroup roles")
 		}
 	}
@@ -179,14 +181,23 @@ func (a *Manager) patchAWSNodeDaemonSet() error {
 
 	return nil
 }
-func (a *Manager) getRecommendedPolicies(addon *api.Addon) []string {
+
+func (a *Manager) hasRecommendedPolicies(addon *api.Addon) bool {
+	attachPolicyARNs, wellKnownPolicies := a.getRecommendedPolicies(addon)
+	return attachPolicyARNs != nil || wellKnownPolicies != nil
+}
+
+func (a *Manager) getRecommendedPolicies(addon *api.Addon) ([]string, *api.WellKnownPolicies) {
 	// API isn't case sensitive
 	switch addon.CanonicalName() {
 	case vpcCNIName:
-		return []string{fmt.Sprintf("arn:%s:iam::aws:policy/%s", api.Partition(a.clusterConfig.Metadata.Region), api.IAMPolicyAmazonEKSCNIPolicy)}
-	default:
-		return []string{}
+		return []string{fmt.Sprintf("arn:%s:iam::aws:policy/%s", api.Partition(a.clusterConfig.Metadata.Region), api.IAMPolicyAmazonEKSCNIPolicy)}, nil
+	case ebsCSIDriverName:
+		return nil, &api.WellKnownPolicies{
+			EBSCSIController: true,
+		}
 	}
+	return nil, nil
 }
 
 func (a *Manager) getKnownServiceAccountLocation(addon *api.Addon) (string, string) {
